==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/inputs/ParameterValuesValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin.inputs

import com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The value of a parameter.
 * @property value The value of the parameter.
 */
public data class ParameterValuesValueArgs(
    public val `value`: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs> {
    override fun toJava(): com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs =
        com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ParameterValuesValueArgs].
 */
@PulumiTagMarker
public class ParameterValuesValueArgsBuilder internal constructor() {
    private var `value`: Output<Any>? = null

    /**
     * @param value The value of the parameter.
     */
    @JvmName("rswhhppywpuqqoxm")
    public suspend fun `value`(`value`: Output<Any>) {
        this.`value` = value
    }

    /**
     * @param value The value of the parameter.
     */
    @JvmName("rxtmgwixcywknkiv")
    public suspend fun `value`(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ParameterValuesValueArgs = ParameterValuesValueArgs(
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/inputs/ParameterValuesValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin.inputs

import com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The value of a parameter.
 * @property value The value of the parameter.
 */
public data class ParameterValuesValueArgs(
    public val `value`: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs> {
    override fun toJava(): com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs =
        com.pulumi.azurenative.authorization.inputs.ParameterValuesValueArgs.builder()
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ParameterValuesValueArgs].
 */
@PulumiTagMarker
public class ParameterValuesValueArgsBuilder internal constructor() {
    private var `value`: Output<Any>? = null

    /**
     * @param value The value of the parameter.
     */
    @JvmName("nifvafouedmywswj")
    public suspend fun `value`(`value`: Output<Any>) {
        this.`value` = value
    }

    /**
     * @param value The value of the parameter.
     */
    @JvmName("xcymtngsukoifbwg")
    public suspend fun `value`(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ParameterValuesValueArgs = ParameterValuesValueArgs(
        `value` = `value`,
    )
}
